<?php

namespace apexl\Io\modules\display\components\form;

use apexl\Io\modules\component\entities\componentEntity;

class NumberField extends InputField
{
    
    public function __construct($fieldName)
    {
        parent::__construct($fieldName);
        $this->setInputType('number');
    }
}
