<?php

namespace apexl\Io\modules\display\pages;

use apexl\Io\modules\display\includes\Page;

class homePage extends Page
{
    public function __construct()
    {
        parent::__construct();
    }

    public function authenticatedDashboard()
    {
        return $this->getPage();
    }
}
