<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\includes\Routes;
use apexl\Io\modules\component\entities\componentEntity;

class FilteredChild extends componentEntity
{
    public function __construct()
    {
        parent::__construct();

    }

    public function setContentSrc($src, $data=[])
    {
        $this->addProperty('contentSrc', Routes::getRoutePattern($src, $data, false));
        return $this;
    }

}
