<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class DateSelectWrapper extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
        //$this->setColWidth('md', 12);
    }

    public function addTitle($text): ColWrapper
    {
        $this->addProperty('title', $text);
        return $this;
    }

    public function setStartDate(\DateTime $startTime)
    {
        $this->addProperty('startDate', $startTime->format('Y-m-d'));
        return $this;
    }

    public function setEndDate(\DateTime $endTime)
    {
        $this->addProperty('endDate', $endTime->format('Y-m-d'));
        return $this;
    }
}
